Contatti | IFM Group
Author: IFM GROUP
Description: IFM Group opera nel mercato italiano delle tecnologie evolute di comunicazione. Offre soluzioni integrate per Telecomunicazioni, Unified Communications, Customer Relationship Management e tecnologie Multisensoriali.
Keywords: telecomunicazioni, unified communications, CRM, contact center, human security, m2m2p

Salta al contenuto principale
Contatti|Scrivici per avere maggiori informazioni
NOME *
COGNOME *
AZIENDA *
TELEFONO *
EMAIL *
OGGETTO *
MESSAGGIO *
Privacy Policy *
La presente informativa, resa anche ai sensi dell'art. 13 del d.lgs. n. 196/2003 - Codice in materia di protezione dei dati personali, descrive le modalità di gestione del sito di IFM Infomaster S.p.A.(di seguito il Sito) in riferimento al trattamento dei dati personali degli utenti che vi accedono e che interagiscono con esso. Le informazioni e i dati del Sito sono e rimangono di proprietà della IFM medesima e l’utente si impegna a non utilizzarli o trattarli in modo incompatibile con tale titolo. Il titolare del trattamento dei dati è la IFM Infomaster S.p.A. I tipi di dati trattati sono dati di navigazione e dati comunicati volontariamente dall’utente. I sistemi informatici e le procedure software preposte al funzionamento di questo sito web acquisiscono, nel corso del loro normale esercizio, alcuni dati personali la cui trasmissione è implicita nell’uso dei protocolli di comunicazione di Internet. Si tratta di informazioni che non sono raccolte per essere associate a specifici soggetti/utenti (ad esempio indirizzi IP). L’invio facoltativo o esplicito e volontario di posta elettronica agli indirizzi indicati su questo Sito comporta la successiva acquisizione dell’indirizzo mail del mittente, necessario per rispondere alle richieste, nonché degli eventuali altri dati personali inseriti nella missiva. Tali dati personali sono trattati in conformità alla vigente normativa e secondo le misure di sicurezza predisposte da IFM per garantire il rispetto del Disciplinare Tecnico in Materia di Misure Minime di Sicurezza – Allegato B al Codice Della Privacy. I dati personali sono raccolti e trattati con strumenti automatizzati per il tempo strettamente necessario a conseguire gli scopi per cui sono stati raccolti. I soggetti cui si riferiscono i dati personali hanno il diritto in qualunque momento di ottenere la conferma dell’esistenza o meno dei medesimi dati e di conoscerne il contenuto e l’origine,verificarne l’esattezza o chiederne l’integrazione o l’aggiornamento, oppure la rettificazione. Il soggetto interessato ha il diritto di chiedere la cancellazione, la trasformazione in forma anonima o il blocco dei dati trattati in violazione di legge, nonché di opporsi in ogni caso, per motivi legittimi, al loro trattamento. A tali soggetti spettano in ogni caso i diritti di cui agli artt. 7 e 8 del Dlgs 196/03,e sue successive modifiche ed integrazioni. Le richieste precedentemente descritte vanno rivolte a IFM in forma scritta.
Accetto i termini e le condizioni sulla privacy

- EN
- DE